SystemOrganization addCategory: #'GT-EventRecorder-Tests'!
SystemOrganization addCategory: 'GT-EventRecorder-Tests-Core'!
SystemOrganization addCategory: 'GT-EventRecorder-Tests-Identifier'!

TestCase subclass: #GTEventBundleTest
	instanceVariableNames: 'bundle data category url entity'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventBundleTest commentStamp: '<historical>' prior: 0!
A GTEventBundleTest is a test class for testing the behavior of GTEventBundle!

!GTEventBundleTest methodsFor: 'running' stamp: 'JurajKubelka 11/15/2015 11:08'!
setUp
	super setUp.
	bundle := GTEventBundle new.
	data := #[1 2 3 4].
	category := #category1.
	url := 'http://localhost/gt/events' asZnUrl.
	! !

!GTEventBundleTest methodsFor: 'tests' stamp: 'JurajKubelka 11/20/2015 09:02'!
testData
	"It is really important that it is the same object."
	bundle data: data.
	self assert: bundle data == bundle data.! !

!GTEventBundleTest methodsFor: 'tests' stamp: 'JurajKubelka 11/15/2015 11:11'!
testEntity
	bundle data: data.
	entity := bundle entity.
	self assert: (entity isKindOf: ZnByteArrayEntity).
	self assert: entity bytes equals: data.! !

TestCase subclass: #GTEventCollectorTest
	instanceVariableNames: 'collector'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventCollectorTest commentStamp: '<historical>' prior: 0!
A GTEventCollectorTest is a test class for testing the behavior of GTEventCollector!

!GTEventCollectorTest methodsFor: 'running' stamp: 'JurajKubelka 10/11/2015 14:19'!
setUp
	super setUp.
	collector := GTEventCollector new! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 10/11/2015 14:21'!
testBundle
	self assert: collector bundle isEmpty! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 10/11/2015 14:22'!
testBundle2
	collector add: GTDummyEvent new.
	collector add: GTDummyEvent new.
	self assert: collector bundle size equals: 2.
	self assert: collector bundle isEmpty.! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 11/13/2015 22:29'!
testCategory
	self assert: collector category equals: collector defaultCategory! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 19:27'!
testIsLiberated
	"By default it is liberated."
	self assert: collector isLiberated! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 19:28'!
testIsLiberated2
	"The collection of events has to be empty."
	collector add: 42.
	self deny: collector isLiberated.! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 19:29'!
testIsLiberated3
	"The occupant has to be empty."
	collector occupant: self.
	self deny: collector isLiberated.! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 19:53'!
testLiberate
	collector liberate.
	self assert: collector isLiberated! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 19:54'!
testLiberate2
	collector occupant: self.
	self deny: collector isLiberated.
	collector liberate.
	self assert: collector isLiberated! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 10/11/2015 20:10'!
testPrintOn
	self assert: (String streamContents: [ :stream | collector printOn: stream ]) notEmpty.! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 12/21/2015 11:38'!
testUpdateAnnouncement
	| announcement announcement2 |
	collector updateAnnouncementBlock: [ :anAnnouncement | 
		anAnnouncement at: #testUpdateAnnouncement put: 42 ].
	announcement := GTEventAnnouncement new.
	self assert: (announcement at: #testUpdateAnnouncement) isNil.
	announcement2 := collector updateAnnouncement: announcement.
	self assert: announcement == announcement2.
	self assert: (announcement at: #testUpdateAnnouncement) equals: 42.! !

!GTEventCollectorTest methodsFor: 'tests' stamp: 'JurajKubelka 10/11/2015 14:19'!
testUrl
	self assert: collector url notNil.
	self assert: collector url equals: GTEventRecorderSettings url.! !

TestCase subclass: #GTEventCollectorsTest
	instanceVariableNames: 'collectors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventCollectorsTest commentStamp: '<historical>' prior: 0!
A GTEventCollectorsTest is a test class for testing the behavior of GTEventCollectors!

!GTEventCollectorsTest methodsFor: 'running' stamp: 'JurajKubelka 10/11/2015 20:11'!
setUp
	super setUp.
	collectors := GTEventCollectors new.! !

!GTEventCollectorsTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 15:04'!
testAdd
	collectors add: GTEventCollector new.
	self assert: collectors size equals: 1.! !

!GTEventCollectorsTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 15:04'!
testAdd2
	collectors add: GTEventCollector new.
	collectors add: GTEventCollector new.
	self assert: collectors size equals: 2.! !

!GTEventCollectorsTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 15:05'!
testAdd3
	| collector |
	collector := GTEventCollector new.
	collectors add: collector.
	collectors add: collector.
	self assert: collectors size equals: 1.! !

!GTEventCollectorsTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 15:05'!
testDefault
	self assert: collectors size equals: 0.! !

!GTEventCollectorsTest methodsFor: 'tests' stamp: 'JurajKubelka 1/29/2016 10:36'!
testDo
	"Ensure that collectors are iterated in the same order as they are added."
	| collector1 collector2 interatedCollectors |
	collector1 := GTEventCollector new.
	collector2 := GTEventCollector new.
	collectors add: collector2.
	collectors add: collector1.
	interatedCollectors := OrderedCollection new.
	collectors do: [ :eachCollector | interatedCollectors addLast: eachCollector ].
	self assert: interatedCollectors size equals: 2.
	self assert: interatedCollectors first == collector2.
	self assert: interatedCollectors second == collector1.
	! !

!GTEventCollectorsTest methodsFor: 'tests' stamp: 'JurajKubelka 1/29/2016 10:36'!
testDo2
	"Ensure that collectors are iterated in the same order as they are added."
	| collector1 collector2 interatedCollectors |
	collector1 := GTEventCollector new.
	collector2 := GTEventCollector new.
	collectors add: collector1.
	collectors add: collector2.
	interatedCollectors := OrderedCollection new.
	collectors do: [ :eachCollector | interatedCollectors addLast: eachCollector ].
	self assert: interatedCollectors size equals: 2.
	self assert: interatedCollectors first == collector1.
	self assert: interatedCollectors second == collector2.
	! !

!GTEventCollectorsTest methodsFor: 'tests' stamp: 'JurajKubelka 10/11/2015 20:11'!
testPrintOn
	self assert: (String streamContents: [ :stream | collectors printOn: stream ]) notEmpty.! !

TestCase subclass: #GTEventConsolidateTest
	instanceVariableNames: 'consolidate collector1 collector2 collector3 collectors consolidated data'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventConsolidateTest commentStamp: '<historical>' prior: 0!
A GTEventConsolidateTest is a test class for testing the behavior of GTEventConsolidate!

!GTEventConsolidateTest methodsFor: 'running' stamp: 'JurajKubelka 11/17/2015 13:25'!
setUp
	super setUp.
	data := { 42. 'string'. Float pi }.
	consolidate := GTEventConsolidate new.
	collector1 := GTEventCollector new.
	collector2 := GTEventCollector new.
	collector3 := GTEventCollector new.
	collectors := Array with: collector1 with: collector2 with: collector3.
	! !

!GTEventConsolidateTest methodsFor: 'tests' stamp: 'JurajKubelka 11/17/2015 13:42'!
testConsolidated
	"Test that all collectors are consolidated into one."
	collector1 add: data first.
	collector2 add: data second.
	collector3 add: data third.
	consolidate collectors: collectors.
	consolidated := consolidate consolidated.
	self assert: consolidated size equals: 1.
	self assert: consolidated first bundle asArray equals: data.! !

!GTEventConsolidateTest methodsFor: 'tests' stamp: 'JurajKubelka 11/17/2015 13:41'!
testConsolidated2
	"Test that all collectors are consolidated into one."
	collector1 add: data first.
	collector1 add: data second.
	collector2 add: data third.
	consolidate collectors: collectors.
	consolidated := consolidate consolidated.
	self assert: consolidated size equals: 1.
	self assert: consolidated first bundle asArray equals: data.! !

!GTEventConsolidateTest methodsFor: 'tests' stamp: 'JurajKubelka 11/17/2015 13:41'!
testConsolidated3
	"Test that all collectors are consolidated according to URL."
	collector1 add: data first; url: 'http://localhost/1' asZnUrl.
	collector2 add: data second; url: 'http://localhost/2' asZnUrl.
	collector3 add: data third; url: 'http://localhost/1' asZnUrl.
	consolidate collectors: collectors.
	consolidated := consolidate consolidated.
	self assert: consolidated size equals: 2.
	self assert: consolidated first bundle asArray equals: {data first. data third}.
	self assert: consolidated second bundle asArray equals: {data second}.
	! !

!GTEventConsolidateTest methodsFor: 'tests' stamp: 'JurajKubelka 11/17/2015 13:42'!
testConsolidated4
	"Test that all collectors are consolidated according to URL."
	collector1 add: data first; category: #c1.
	collector2 add: data second; category: #c2.
	collector3 add: data third; category: #c1.
	consolidate collectors: collectors.
	consolidated := consolidate consolidated.
	self assert: consolidated size equals: 2.
	self assert: consolidated first bundle asArray equals: {data first. data third}.
	self assert: consolidated second bundle asArray equals: {data second}.
	! !

TestCase subclass: #GTEventDeliveryTest
	instanceVariableNames: 'delivery announcer semaphore'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventDeliveryTest commentStamp: '<historical>' prior: 0!
A GTEventDeliveryTest is a test class for testing the behavior of GTEventDelivery!

!GTEventDeliveryTest methodsFor: 'converting' stamp: 'JurajKubelka 10/11/2015 20:21'!
assertSemaphore
	self deny: (semaphore waitTimeoutMSecs: 200)! !

!GTEventDeliveryTest methodsFor: 'testing' stamp: 'JurajKubelka 10/11/2015 20:22'!
isGlobalRecorder
	^ false! !

!GTEventDeliveryTest methodsFor: 'running' stamp: 'JurajKubelka 11/15/2015 09:32'!
setUp
	super setUp.
	semaphore := Semaphore new.
	delivery := GTEventDelivery new! !

!GTEventDeliveryTest methodsFor: 'running' stamp: 'JurajKubelka 10/11/2015 20:17'!
tearDown
	super tearDown.
	delivery deactivate.! !

!GTEventDeliveryTest methodsFor: 'tests' stamp: 'JurajKubelka 10/11/2015 20:13'!
testPrintOn
	self assert: (String streamContents: [ :stream | delivery printOn: stream ]) notEmpty.! !

!GTEventDeliveryTest methodsFor: 'tests' stamp: 'JurajKubelka 11/13/2015 22:23'!
testPrintOn2
	| string |
	delivery recorder: self.
	delivery preSuspendingAction: [ semaphore signal ].
	delivery activate.	
	self assertSemaphore.
	200 milliSeconds wait.
	string := String streamContents: [ :stream | delivery printOn: stream ].
	self assert: string notEmpty.
	self assert: (string includesSubstring: 'next cycle in').! !

!GTEventDeliveryTest methodsFor: 'tests' stamp: 'JurajKubelka 10/11/2015 20:14'!
testPrintProcessName
	self assert: delivery printProcessName isNotEmpty! !

TestCase subclass: #GTEventMultiBundleFactoryTest
	instanceVariableNames: 'bundle1 bundle2 bundle3 bundle4 factory multiBundles multiBundle1 multiBundle2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventMultiBundleFactoryTest commentStamp: '<historical>' prior: 0!
A GTEventMultiBundleFactoryTest is a test class for testing the behavior of GTEventMultiBundleFactory!

!GTEventMultiBundleFactoryTest methodsFor: 'accessing' stamp: 'JurajKubelka 11/15/2015 10:02'!
allBundles
	^ { bundle1. bundle2. bundle3. bundle4 }! !

!GTEventMultiBundleFactoryTest methodsFor: 'private' stamp: 'JurajKubelka 11/15/2015 10:17'!
detectEvents
	multiBundle1 := multiBundles first.
	multiBundle2 := multiBundles second.
	! !

!GTEventMultiBundleFactoryTest methodsFor: 'running' stamp: 'JurajKubelka 11/15/2015 09:50'!
setUp
	super setUp.
	bundle1 := GTEventBundle new 
		url: 'http://localhost/gt/events1' asZnUrl; category: #c1; data: #[1 2 3]; yourself.
	bundle2 := GTEventBundle new 
		url: 'http://localhost/gt/events1' asZnUrl; category: #c1; data: #[4 5 6]; yourself.
	bundle3 := GTEventBundle new 
		url: 'http://localhost/gt/events1' asZnUrl; category: #c2; data: #[7 8 9]; yourself.
	bundle4 := GTEventBundle new 
		url: 'http://localhost/gt/events2' asZnUrl; category: #c1; data: #[10 11 12]; yourself.
	factory := GTEventMultiBundleFactory new.! !

!GTEventMultiBundleFactoryTest methodsFor: 'tests' stamp: 'JurajKubelka 11/15/2015 10:17'!
testFromBundles
	multiBundles := factory fromBundles: self allBundles.
	self assert: multiBundles size equals: 2.
	self detectEvents.
	self assert: multiBundle1 url equals: bundle1 url.
	self deny: multiBundle1 bundles isEmpty.
	self assert: multiBundle2 url equals: bundle4 url.
	self deny: multiBundle2 bundles isEmpty.
	self assert: multiBundle1 bundles size equals: 3.
	self assert: multiBundle2 bundles size equals: 1.
	self assert: multiBundle1 bundles first equals: bundle1.
	self assert: multiBundle1 bundles second equals: bundle2.
	self assert: multiBundle1 bundles third equals: bundle3.
	self assert: multiBundle2 bundles first equals: bundle4.
! !

!GTEventMultiBundleFactoryTest methodsFor: 'tests' stamp: 'AndreiChis 11/19/2015 20:28'!
testFromBundles2
	"#fromBundles: can also receive GTMultiBundle object. It should be consolidate too."
	multiBundles := factory fromBundles: self allBundles.
	multiBundles := factory fromBundles: (self allBundles copy asOrderedCollection
		addAll: multiBundles;
		yourself) asArray.
	self assert: multiBundles size equals: 2.
	self detectEvents.
	self assert: multiBundle1 url equals: bundle1 url.
	self deny: multiBundle1 bundles isEmpty.
	self assert: multiBundle2 url equals: bundle4 url.
	self deny: multiBundle2 bundles isEmpty.
	self assert: multiBundle1 bundles size equals: 6.
	self assert: multiBundle2 bundles size equals: 2.
	self assert: multiBundle1 bundles first equals: bundle1.
	self assert: multiBundle1 bundles second equals: bundle2.
	self assert: multiBundle1 bundles third equals: bundle3.
	self assert: multiBundle1 bundles fourth equals: bundle1.
	self assert: multiBundle1 bundles fifth equals: bundle2.
	self assert: multiBundle1 bundles sixth equals: bundle3.
	self assert: multiBundle2 bundles first equals: bundle4.
	self assert: multiBundle2 bundles second equals: bundle4.
! !

!GTEventMultiBundleFactoryTest methodsFor: 'tests' stamp: 'AndreiChis 11/19/2015 20:28'!
testFromBundles3
	"#fromBundles: can also receive GTMultiBundle object. It should be consolidate too."
	multiBundles := factory fromBundles: self allBundles.
	multiBundles := factory fromBundles: (multiBundles copy asOrderedCollection
		addAll: self allBundles;
		yourself) asArray.
	self assert: multiBundles size equals: 2.
	self detectEvents.
	self assert: multiBundle1 url equals: bundle1 url.
	self deny: multiBundle1 bundles isEmpty.
	self assert: multiBundle2 url equals: bundle4 url.
	self deny: multiBundle2 bundles isEmpty.
	self assert: multiBundle1 bundles size equals: 6.
	self assert: multiBundle2 bundles size equals: 2.
	self assert: multiBundle1 bundles first equals: bundle1.
	self assert: multiBundle1 bundles second equals: bundle2.
	self assert: multiBundle1 bundles third equals: bundle3.
	self assert: multiBundle1 bundles fourth equals: bundle1.
	self assert: multiBundle1 bundles fifth equals: bundle2.
	self assert: multiBundle1 bundles sixth equals: bundle3.
	self assert: multiBundle2 bundles first equals: bundle4.
	self assert: multiBundle2 bundles second equals: bundle4.
! !

!GTEventMultiBundleFactoryTest methodsFor: 'tests' stamp: 'JurajKubelka 11/18/2015 14:15'!
testFromBundles4
	"#fromBundles: can also receive GTMultiBundle object. It should be consolidate too."
	multiBundles := factory fromBundles: self allBundles.
	multiBundles := factory fromBundles: multiBundles.
	self assert: multiBundles size equals: 2.
	self detectEvents.
	self assert: multiBundle1 url equals: bundle1 url.
	self deny: multiBundle1 bundles isEmpty.
	self assert: multiBundle2 url equals: bundle4 url.
	self deny: multiBundle2 bundles isEmpty.
	self assert: multiBundle1 bundles size equals: 3.
	self assert: multiBundle2 bundles size equals: 1.
	self assert: multiBundle1 bundles first equals: bundle1.
	self assert: multiBundle1 bundles second equals: bundle2.
	self assert: multiBundle1 bundles third equals: bundle3.
	self assert: multiBundle2 bundles first equals: bundle4.
! !

TestCase subclass: #GTEventMultiBundleTest
	instanceVariableNames: 'bundle1 bundle2 bundle3 multiBundle entity'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventMultiBundleTest commentStamp: '<historical>' prior: 0!
A GTEventMultiBundleTest is a test class for testing the behavior of GTEventMultiBundle!

!GTEventMultiBundleTest methodsFor: 'running' stamp: 'JurajKubelka 11/15/2015 10:44'!
setUp
	super setUp.
	bundle1 := GTEventBundle new 
		url: 'http://localhost/gt/events1' asZnUrl; category: #c1; data: #[1 2 3]; yourself.
	bundle2 := GTEventBundle new 
		url: 'http://localhost/gt/events1' asZnUrl; category: #c1; data: #[4 5 6]; yourself.
	bundle3 := GTEventBundle new 
		url: 'http://localhost/gt/events1' asZnUrl; category: #c2; data: #[7 8 9]; yourself.
	multiBundle := GTEventMultiBundle new.
! !

!GTEventMultiBundleTest methodsFor: 'tests' stamp: 'JurajKubelka 11/15/2015 10:45'!
testEntity
	self assert: multiBundle entity isEmpty! !

!GTEventMultiBundleTest methodsFor: 'tests' stamp: 'JurajKubelka 11/15/2015 10:56'!
testEntity2
	multiBundle add: bundle1.
	entity := multiBundle entity.
	self deny: entity isEmpty.
	self assert: entity parts size equals: 2.
	self assert: entity parts first fieldName equals: 'category'.
	self assert: entity parts second fieldName equals: 'data'.
	self assert: entity parts first fieldValue equals: #c1.
	self assert: entity parts second fieldValue equals: #[1 2 3].
	! !

!GTEventMultiBundleTest methodsFor: 'tests' stamp: 'JurajKubelka 11/15/2015 11:16'!
testEntity3
	multiBundle add: bundle1; add: bundle2.
	entity := multiBundle entity.
	self deny: entity isEmpty.
	self assert: entity parts size equals: 4.
	self assert: entity parts first fieldName equals: 'category'.
	self assert: entity parts second fieldName equals: 'data'.
	self assert: entity parts third fieldName equals: 'category'.
	self assert: entity parts fourth fieldName equals: 'data'.
	self assert: entity parts first fieldValue equals: #c1.
	self assert: entity parts second fieldValue equals: #[1 2 3].
	self assert: entity parts third fieldValue equals: #c1.
	self assert: entity parts fourth fieldValue equals: #[4 5 6].
! !

!GTEventMultiBundleTest methodsFor: 'tests' stamp: 'JurajKubelka 11/15/2015 11:18'!
testEntity4
	multiBundle add: bundle1; add: bundle2; add: bundle3.
	entity := multiBundle entity.
	self deny: entity isEmpty.
	self assert: entity parts size equals: 6.
	self assert: entity parts first fieldName equals: 'category'.
	self assert: entity parts second fieldName equals: 'data'.
	self assert: entity parts third fieldName equals: 'category'.
	self assert: entity parts fourth fieldName equals: 'data'.
	self assert: entity parts fifth fieldName equals: 'category'.
	self assert: entity parts sixth fieldName equals: 'data'.
	self assert: entity parts first fieldValue equals: #c1.
	self assert: entity parts second fieldValue equals: #[1 2 3].
	self assert: entity parts third fieldValue equals: #c1.
	self assert: entity parts fourth fieldValue equals: #[4 5 6].
	self assert: entity parts fifth fieldValue equals: #c2.
	self assert: entity parts sixth fieldValue equals: #[7 8 9].
! !

TestCase subclass: #GTEventPackingTest
	instanceVariableNames: 'packing event1 event2 collector bundle announcement unpackedData storage file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventPackingTest commentStamp: '<historical>' prior: 0!
A GTEventPackingTest is a test class for testing the behavior of GTEventPacking!

!GTEventPackingTest class methodsFor: 'testing' stamp: 'JurajKubelka 10/10/2015 15:22'!
isAbstract
	^ self name = GTEventPackingTest name! !

!GTEventPackingTest methodsFor: 'asserting' stamp: 'JurajKubelka 11/15/2015 09:29'!
assertBundle
	bundle := packing pack: collector.
	self assert: bundle url equals: collector url.
	self assert: bundle data isLiteral.
	self assert: bundle category equals: collector category.! !

!GTEventPackingTest methodsFor: 'asserting' stamp: 'JurajKubelka 10/31/2015 22:11'!
assertUnpackedData
	unpackedData := announcement unpackedData.
	self assert: unpackedData size equals: 2.
	self assert: unpackedData first equals: event1.
	self assert: unpackedData second equals: event2! !

!GTEventPackingTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 15:23'!
packingClass
	^ self subclassResponsibility! !

!GTEventPackingTest methodsFor: 'running' stamp: 'JurajKubelka 1/29/2016 12:08'!
setUp
	super setUp.
	event1 := GTDummyEvent new data: 'string'.
	event2 := GTDummyEvent new data: 42.
	collector := GTEventCollector new.
	collector add: event1; add: event2.
	collector category: #category1.
	packing := self packingClass new.
	storage := FileSystem memory.
	file := storage workingDirectory / 'data'.
! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 1/29/2016 12:08'!
testNewAnnouncementFor
	announcement := packing newAnnouncementFor: collector.
	self assert: announcement serializedBy equals: packing class name.
	self assert: announcement eventRecorderVersion equals: packing version.
	self assert: announcement category equals: collector category.! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 12/21/2015 11:45'!
testNewAnnouncementFor2
	collector updateAnnouncementBlock: [ :anAnnouncement | 
		anAnnouncement at: #testNewAnnouncementFor2 put: 42 ].
	announcement := packing newAnnouncementFor: collector.
	self assert: announcement serializedBy equals: packing class name.
	self assert: announcement eventRecorderVersion equals: packing version.
	self assert: (announcement at: #testNewAnnouncementFor2) equals: 42.! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 10/31/2015 22:14'!
testPack
	self assertBundle.
	announcement := packing unpack: bundle data.
	self assertUnpackedData! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 10/31/2015 22:24'!
testUnpackBinaryBinaryStream
	self assertBundle.
	file writeStreamDo: [ :aStream | 
		aStream binary.
		aStream nextPutAll: bundle data ].
	file binaryReadStreamDo: [ :aStream | 
		announcement := packing unpack: aStream contents ].
	self assertUnpackedData.
! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 10/31/2015 22:24'!
testUnpackBinaryUnspecifiedStream
	self assertBundle.
	file writeStreamDo: [ :aStream | 
		aStream binary.
		aStream nextPutAll: bundle data ].
	announcement := packing unpack: file contents.
	self assertUnpackedData.! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 10/31/2015 22:23'!
testUnpackUnspecifiedBinaryStream
	self assertBundle.
	file writeStreamDo: [ :aStream | 
		aStream nextPutAll: bundle data ].
	file binaryReadStreamDo: [ :aStream | 
		announcement := packing unpack: aStream contents ].
	self assertUnpackedData.
! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 10/31/2015 22:25'!
testUnpackUnspecifiedUnspecifiedStream
	self assertBundle.
	file writeStreamDo: [ :aStream | 
		aStream nextPutAll: bundle data ].
	announcement := packing unpack: file contents.
	self assertUnpackedData.! !

GTEventPackingTest subclass: #GTFuelPackingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTFuelPackingTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 15:23'!
packingClass
	^ GTFuelPacking! !

!GTFuelPackingTest methodsFor: 'tests' stamp: 'JurajKubelka 11/2/2015 13:48'!
testMigration
	| oldClass oldObject |
	oldClass := Object newAnonymousSubclass.
	oldObject := oldClass new.
	collector := GTEventCollector new.
	collector add: oldObject.
	bundle := packing pack: collector.
	announcement := packing unpack: bundle data.
	self should: [ announcement unpackedData ] raise: FLClassNotFound.! !

!GTFuelPackingTest methodsFor: 'tests' stamp: 'JurajKubelka 11/2/2015 13:48'!
testMigration2
	| oldClass oldObject |
	oldClass := Object newAnonymousSubclass.
	oldObject := oldClass new.
	collector := GTEventCollector new.
	collector add: oldObject.
	bundle := packing pack: collector.
	packing addMigration: [ :aMaterializer |
		aMaterializer migrateClassNamed: oldClass name asSymbol toClass: GTDummyEvent ].
	announcement := packing unpack: bundle data.
	announcement migrationRules: packing migrations.
	unpackedData := announcement unpackedData.
	self assert: unpackedData isCollection.
	self assert: unpackedData size equals: 1.
	self assert: unpackedData anyOne class equals: GTDummyEvent.! !

GTEventPackingTest subclass: #GTStonPackingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTStonPackingTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 15:24'!
packingClass
	^ GTStonPacking! !

TestCase subclass: #GTEventRecorderTest
	instanceVariableNames: 'recorder server event1 event2 delegate receivedContents semaphore receiverSemaphore collector1 collector2 event3 event4'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventRecorderTest methodsFor: 'asserting' stamp: 'JurajKubelka 10/9/2015 21:37'!
assertReceiverSemaphore
	self deny: (receiverSemaphore waitTimeoutMSecs: 200)! !

!GTEventRecorderTest methodsFor: 'asserting' stamp: 'JurajKubelka 10/9/2015 21:30'!
assertSemaphore
	self deny: (semaphore waitTimeoutMSecs: 200)! !

!GTEventRecorderTest methodsFor: 'asserting' stamp: 'JurajKubelka 11/13/2015 22:27'!
denyReceiverSemaphore
	self assert: (receiverSemaphore waitTimeoutMSecs: 200)! !

!GTEventRecorderTest methodsFor: 'server handling' stamp: 'JurajKubelka 10/9/2015 21:37'!
handleRequest: request response: response
	receivedContents nextPut: request contents.
	receiverSemaphore signal.
	^ response! !

!GTEventRecorderTest methodsFor: 'running' stamp: 'JurajKubelka 1/7/2016 19:12'!
setUp
	super setUp.
	self setUpServer.
	semaphore := Semaphore new.
	recorder := GTEventRecorder new.
	recorder offerPrivacy; offerDeliveryPermission.
	collector1 := GTEventCollector new.
	collector1 url: server url.
	collector2 := GTEventCollector new.
	collector2 url: server url.
	event1 := GTDummyEvent new data: 'string1'.
	event2 := GTDummyEvent new data: 42.
	event3 := GTDummyEvent new data: #symbol1.
	event4 := GTDummyEvent new data: 42.0.
	! !

!GTEventRecorderTest methodsFor: 'running' stamp: 'JurajKubelka 11/15/2015 17:44'!
setUpServer
	receivedContents := WaitfreeQueue new.
	receiverSemaphore := Semaphore new.
	delegate := ZnDispatcherDelegate new.
	delegate
		map: '/'
		to: [ :request :response | self handleRequest: request response: response ].
	server := GTEventRecorderTestServer new.
	server initializeUsingDelegate: delegate semaphore: receiverSemaphore.! !

!GTEventRecorderTest methodsFor: 'running' stamp: 'JurajKubelka 11/16/2015 18:31'!
tearDown
	super tearDown.
	recorder deactivateDelivery.
	server stop.
	server unsubscribeAll.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 10:29'!
testAddCollector
	recorder addCollector: GTEventCollector new.
	self assert: recorder numberOfCollectors equals: 1.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 11:53'!
testAddCollector2
	recorder addCollector: GTEventCollector new.
	self assert: recorder isDeliveryActive.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/13/2015 22:23'!
testAddCollector3
	recorder addCollector: collector1.
	collector1 add: event1.
	collector1 add: event2.
	recorder deliveryPreSuspendingAction: [ semaphore signal ].
	self assertSemaphore.
	self waitForDelivery.
	self assert: collector1 size equals: 0.
	self assert: receivedContents size equals: 1.
	! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/13/2015 16:52'!
testAddCollector4
	recorder addCollector: collector1.
	collector1 add: event1.
	collector1 add: event2.
	recorder delivery packAndDeliver: false.
	"wait"
	self assert: collector1 size equals: 0.
	! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 15:00'!
testAddCollector5
	recorder addCollector: GTEventCollector new.
	recorder addCollector: GTEventCollector new.
	self assert: recorder numberOfCollectors equals: 2.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/13/2015 16:52'!
testAddCollector6
	recorder addCollector: collector1.
	recorder addCollector: collector1.
	self assert: recorder numberOfCollectors equals: 1.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/13/2015 22:27'!
testDeliverAllInOneHttpRequest
	collector1 category: #category1.
	collector2 category: #category2.
	collector1 add: event1; add: event2.
	collector2 add: event3; add: event4.
	recorder deliveryPreSuspendingAction: [ semaphore signal ].
	recorder addCollector: collector1.
	recorder addCollector: collector2.
	self assertSemaphore.
	self waitForDelivery.
	self denyReceiverSemaphore.
	self assert: collector1 size equals: 0.
	self assert: collector2 size equals: 0.
	self assert: receivedContents size equals: 1.
! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 11:56'!
testDeliverNow
	"Just test that we can ask for delivering."
	recorder deliverNow! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 19:44'!
testDeliverNow2
	"Ensure that liberated collector is removed."
	recorder deliveryPreSuspendingAction: [ semaphore signal ].
	collector1 add: 42.
	recorder addCollector: collector1.
	self assertSemaphore.
	recorder deliverNow.
	self assertSemaphore.
	self assert: collector1 size equals: 0.
	self assert: recorder numberOfCollectors equals: 0.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 19:44'!
testDeliverNow3
	"Ensure that collector with registerd holder is not removed."
	recorder deliveryPreSuspendingAction: [ semaphore signal ].
	collector1 add: 42.
	collector1 occupant: self.
	recorder addCollector: collector1.
	self assertSemaphore.
	recorder deliverNow.
	self assertSemaphore.
	self assert: collector1 size equals: 0.
	self assert: recorder numberOfCollectors equals: 1.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 10:40'!
testIsDeliveryActive
	self deny: recorder isDeliveryActive.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/20/2015 08:43'!
testNotDeliveredDataShouldBeResent
	"If the data are not received, we will resent them."
	collector1 category: #category1.
	collector1 add: event1; add: event2.
	"Server will not receive anything."
	server server delegate: ZnDispatcherDelegate new.
	recorder deliveryPreSuspendingAction: [ semaphore signal ].
	recorder addCollector: collector1.
	self assertSemaphore.
	recorder deliverNow.
	self assertSemaphore.
	self denyReceiverSemaphore.
	self assert: collector1 size equals: 0.
	self assert: receivedContents size equals: 0.
	self assert: recorder numberOfDeliveryData equals: 1.
	"Send again."
	server server delegate: delegate.
	self waitForDelivery.
	self denyReceiverSemaphore.
	self assert: receivedContents size equals: 1.
	self assert: recorder numberOfDeliveryData equals: 0.
! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 1/29/2016 12:26'!
testPack
	"Ensure that delivery pack is prepared and collector empty."
	recorder addCollector: collector1.
	collector1 add: event1.
	collector1 add: event2.
	recorder pack.
	self assert: collector1 size equals: 0.
	self assert: recorder delivery size equals: 1.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/17/2015 13:56'!
testPack2
	"Ensure that there is only one delivery pack when collectors are of the same URL and category."
	recorder addCollector: collector1.
	collector1 add: event1.
	collector1 add: event2.
	recorder addCollector: collector2.
	collector2 add: event3.
	collector2 add: event4.
	recorder pack.
	self assert: collector1 size equals: 0.
	self assert: collector2 size equals: 0.
	self assert: recorder delivery size equals: 1.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 1/29/2016 12:42'!
testPack3
	"Ensure that empty collector is not delivered."
	recorder addCollector: collector1.
	self assert: collector1 size equals: 0.
	recorder pack.
	self assert: collector1 size equals: 0.
	self assert: recorder delivery size equals: 0.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/11/2015 15:30'!
testRemoveCollector
	recorder removeCollector: GTEventCollector new.
	self assert: recorder numberOfCollectors equals: 0.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/13/2015 16:52'!
testRemoveCollector2
	recorder addCollector: collector1.
	self assert: recorder isDeliveryActive.
	recorder removeCollector: collector1.
	self deny: recorder isDeliveryActive.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 11/20/2015 09:01'!
testTwiceDeliveredDataSholdBeDetected
	"It happens regularly that the server receives the same data several times.
	We need to be sure that we can detect it easily."
	| bundles data |
	collector1 category: #category1.
	collector1 add: event1; add: event2.
	"Server will not receive anything."
	server server delegate: ZnDispatcherDelegate new.
	recorder deliveryPreSuspendingAction: [ semaphore signal ].
	recorder addCollector: collector1.
	self assertSemaphore.
	recorder deliverNow.
	self assertSemaphore.
	self denyReceiverSemaphore.
	self assert: collector1 size equals: 0.
	self assert: receivedContents size equals: 0.
	self assert: recorder numberOfDeliveryData equals: 1.
	bundles := recorder delivery bundles.
	self assert: bundles size equals: 1.
	self assert: recorder numberOfDeliveryData equals: 0.
	"Send twice."
	server server delegate: delegate.
	recorder delivery deliver: bundles first signalProgress: false.
	recorder delivery deliver: bundles first signalProgress: false.
	self waitForDelivery.
	self waitForDelivery.
	self denyReceiverSemaphore.
	self assert: receivedContents size equals: 2.
	self assert: recorder numberOfDeliveryData equals: 0.
	"Check that we can detect duplication"
	data := OrderedCollection new.
	receivedContents flush: [ :each | data addLast: each ].
	self assert: data first second contents equals: data second second contents.! !

!GTEventRecorderTest methodsFor: 'asserting' stamp: 'JurajKubelka 11/13/2015 16:58'!
waitForDelivery
	recorder deliverNow.
	self assertReceiverSemaphore.! !

TestCase subclass: #GTEventRegistryTest
	instanceVariableNames: 'registry'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventRegistryTest commentStamp: '<historical>' prior: 0!
A GTEventRegistryTest is a test class for testing the behavior of GTEventRegistry!

!GTEventRegistryTest methodsFor: 'running' stamp: 'JurajKubelka 11/16/2015 19:13'!
setUp
	super setUp.
	registry := GTEventRegistry new.! !

!GTEventRegistryTest methodsFor: 'as yet unclassified' stamp: 'JurajKubelka 11/16/2015 19:15'!
testIsLiberated
	"By default it should answer yes."
	self assert: registry isLiberated! !

!GTEventRegistryTest methodsFor: 'as yet unclassified' stamp: 'JurajKubelka 11/16/2015 19:17'!
testIsLiberated2
	"By default it should answer yes."
	registry object: self.
	self deny: registry isLiberated.! !

!GTEventRegistryTest methodsFor: 'as yet unclassified' stamp: 'JurajKubelka 11/16/2015 19:25'!
testIsLiberated3
	"By default it should answer yes."
	registry object: self.
	self deny: registry isLiberated.
	registry object: nil.
	self assert: registry isLiberated.! !

TestCase subclass: #GTEventUnpackingTest
	instanceVariableNames: 'unpacking collector unpackedData initialData bundle'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventUnpackingTest commentStamp: '<historical>' prior: 0!
A GTEventUnpackingTest is a test class for testing the behavior of GTEventUnpacking!

!GTEventUnpackingTest methodsFor: 'running' stamp: 'JurajKubelka 10/30/2015 11:42'!
setUp
	super setUp.
	initialData := #('GT' 'Team' 2015).
	collector := GTEventCollector new.
	initialData do: [ :each | collector add: each ].
	unpacking := GTEventUnpacking default.! !

!GTEventUnpackingTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 12:11'!
testUnpack
	bundle := GTEventPacking default pack: collector.
	unpackedData := unpacking unpack: bundle data.
	self assert: unpackedData class equals: GTEventAnnouncement.
	self assert: unpackedData unpackedData asArray equals: initialData.! !

!GTEventUnpackingTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 12:14'!
testUnpack2
	self should: [ unpacking unpack: initialData ] raise: GTEventUnpackingError! !

!GTEventUnpackingTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 12:40'!
testUnpack3
	bundle := GTEventPacking default pack: collector.
	unpacking := GTEventUnpacking new.
	self should: [ unpacking unpack: bundle data ] raise: GTEventInitializationError! !

!GTEventUnpackingTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 12:41'!
testUnpack4
	bundle := GTEventPacking ston pack: collector.
	unpacking := GTEventUnpacking new.
	unpacking addPacking: GTEventPacking fuel.
	self should: [ unpacking unpack: bundle data ] raise: GTEventUnpackingError ! !

!GTEventUnpackingTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 12:41'!
testUnpack5
	bundle := GTEventPacking fuel pack: collector.
	unpacking := GTEventUnpacking new.
	unpacking addPacking: GTEventPacking ston.
	self should: [ unpacking unpack: bundle data ] raise: GTEventUnpackingError ! !

!GTEventUnpackingTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 12:11'!
testUnpackFuel
	bundle := GTEventPacking fuel pack: collector.
	unpackedData := unpacking unpack: bundle data.
	self assert: unpackedData class equals: GTEventAnnouncement.
	self assert: unpackedData unpackedData asArray equals: initialData.! !

!GTEventUnpackingTest methodsFor: 'tests' stamp: 'JurajKubelka 10/30/2015 12:11'!
testUnpackSton
	bundle := GTEventPacking ston pack: collector.
	unpackedData := unpacking unpack: bundle data.
	self assert: unpackedData class equals: GTEventAnnouncement.
	self assert: unpackedData unpackedData asArray equals: initialData.! !

TestCase subclass: #GlobalIdentifierMergerTest
	instanceVariableNames: 'existing stored merger'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Identifier'!

!GlobalIdentifierMergerTest commentStamp: '<historical>' prior: 0!
A GlobalIdentifierMergerTest is a test class for testing the behavior of GlobalIdentifierMerger!

!GlobalIdentifierMergerTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 19:44'!
setUp
	super setUp.
	existing := Dictionary new.
	stored := Dictionary new.
	merger := GlobalIdentifierMerger new.
	merger existing: existing; stored: stored! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:07'!
testMerge
	"Existing is empty. Stored has value."
	stored at: #a put: 42.
	self assert: merger merge.
	self assert: existing equals: stored.
	self assert: (existing at: #a) equals: 42.
	! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:08'!
testMerge2
	"Existing has something. Stored has another key."
	existing at: #a put: 42.
	stored at: #b put: 21.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 2.
	self assert: stored size equals: 1.
	self assert: (existing at: #a) equals: 42.
	self assert: (existing at: #b) equals: 21.
	! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:08'!
testMerge3
	"Existing has same key as stored."
	existing at: #a put: 42.
	stored at: #a put: 21.
	self deny: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 1.
	self assert: stored size equals: 1.
	self assert: (existing at: #a) equals: 42.
	! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 22:10'!
testMerge4
	"Existing has different computer id as stored."
	existing at: #computerUUID put: 42.
	existing at: #a put: 43.
	existing at: #c put: 44.
	stored at: #computerUUID put: 21.
	stored at: #b put: 22.
	stored at: #c put: 23.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 4.
	self assert: stored size equals: 3.
	self assert: (existing at: #computerUUID) equals: 21 asString.
	self assert: (existing at: #a) equals: 43.
	self assert: (existing at: #b) equals: 22.
	self assert: (existing at: #c) equals: 23.
! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 22:14'!
testMerge5
	"Existing has different computer id as stored."
	existing at: #computerUUID put: 42.
	existing at: #a put: 43.
	existing at: #c put: 44.
	stored at: #b put: 22.
	stored at: #c put: 23.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 4.
	self assert: stored size equals: 2.
	self assert: (existing at: #computerUUID) equals: 42 asString.
	self assert: (existing at: #a) equals: 43.
	self assert: (existing at: #b) equals: 22.
	self assert: (existing at: #c) equals: 44.
! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 22:10'!
testMerge6
	"Existing has different computer id as stored."
	existing at: #a put: 43.
	existing at: #c put: 44.
	stored at: #computerUUID put: 21.
	stored at: #b put: 22.
	stored at: #c put: 23.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 4.
	self assert: stored size equals: 3.
	self assert: (existing at: #computerUUID) equals: 21 asString.
	self assert: (existing at: #a) equals: 43.
	self assert: (existing at: #b) equals: 22.
	self assert: (existing at: #c) equals: 23.
! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 22:01'!
testMerge7
	"Ensure that it converts computerUUID into string."
	stored at: #computerUUID put: UUID new.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: (existing at: #computerUUID) equals: (stored at: #computerUUID) asString.
	! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 22:03'!
testMerge8
	"Ensure that it converts secretUUID into string."
	stored at: #secretUUID put: UUID new.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: (existing at: #secretUUID) equals: (stored at: #secretUUID) asString.
	! !

TestCase subclass: #GlobalIdentifierPersistenceTest
	instanceVariableNames: 'preferences persistence'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Identifier'!

!GlobalIdentifierPersistenceTest commentStamp: '<historical>' prior: 0!
A GlobalIdentifierPersistenceTest is a test class for testing the behavior of GlobalIdentifierPersistence!

GlobalIdentifierPersistenceTest subclass: #GlobalIdentifierFuelPersistenceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Identifier'!

!GlobalIdentifierFuelPersistenceTest commentStamp: '<historical>' prior: 0!
A GlobalIdentifierFuelPersistenceTest is a test class for testing the behavior of GlobalIdentifierFuelPersistence!

!GlobalIdentifierFuelPersistenceTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 16:59'!
persistenceClass
	^ GlobalIdentifierFuelPersistence! !

!GlobalIdentifierFuelPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 17:01'!
setUpPreferences
	preferences := FileLocator workingDirectory / self folderName / 'pharoX' / 'preferences.fuel'.
	preferences ensureDelete.! !

!GlobalIdentifierFuelPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 17:02'!
tearDown
	(FileLocator workingDirectory / self folderName) 
		ensureDeleteAllChildren; 
		ensureDelete.! !

!GlobalIdentifierPersistenceTest class methodsFor: 'testing' stamp: 'JurajKubelka 10/10/2015 16:55'!
isAbstract
	^ self name = GlobalIdentifierPersistenceTest name! !

!GlobalIdentifierPersistenceTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 21:51'!
folderName
	^ 'pharoPreferencesTestFolder'! !

!GlobalIdentifierPersistenceTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 16:58'!
persistenceClass
	^ self subclassResponsibility! !

!GlobalIdentifierPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 16:58'!
setUp
	super setUp.
	self setUpPreferences.
	persistence := self persistenceClass new preferences: preferences; yourself.! !

!GlobalIdentifierPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 16:58'!
setUpPreferences
	self subclassResponsibility! !

!GlobalIdentifierPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 17:02'!
tearDown
	super tearDown.
	preferences ensureDelete.
! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 17:05'!
testDefault
	self deny: preferences exists description: 'The preference file should not exists by default.'.
	self deny: preferences parent exists description: 'The preference directory should not exists by default.'! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:16'!
testDelete
	preferences parent ensureCreateDirectory.
	preferences ensureCreateFile.
	self assert: preferences exists.
	persistence delete.
	self deny: preferences exists.
	! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:16'!
testEnsureDirectory
	persistence ensureDirectory.
	self assert: preferences parent exists.
	self deny: preferences exists.
	! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:19'!
testLoad
	"Load when nothing is stored."
	| values |
	values := Dictionary new.
	values at: #a put: 42.
	persistence load: values.
	self assert: values size equals: 1.
	self assert: (values at: #a) equals: 42.
	self assert: preferences exists.! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:22'!
testLoad2
	"Load stored values."
	| values loaded |
	values := Dictionary new.
	values at: #a put: 42.
	persistence save: values.
	loaded := Dictionary new.
	persistence load: loaded.
	self assert: loaded equals: values.
! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:20'!
testSave
	| values |
	values := Dictionary new.
	values at: #a put: 42.
	persistence save: values.
	self assert: preferences exists.! !

GlobalIdentifierPersistenceTest subclass: #GlobalIdentifierStonPersistenceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Identifier'!

!GlobalIdentifierStonPersistenceTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 21:49'!
persistenceClass
	^ GlobalIdentifierStonPersistence! !

!GlobalIdentifierStonPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 21:50'!
setUpPreferences
	| memory |
	memory := FileSystem memory.
	preferences := memory workingDirectory / self folderName / 'pharoX' / 'preferences.ston'.
	preferences ensureDelete.! !

TestCase subclass: #GlobalIdentifierTest
	instanceVariableNames: 'disk preferences identifier'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Identifier'!

!GlobalIdentifierTest commentStamp: '<historical>' prior: 0!
A GlobalIdentifierTest is a test class for testing the behavior of GlobalIdentifier!

!GlobalIdentifierTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 21:11'!
fileName
	^ identifier persistenceStrategy fileName! !

!GlobalIdentifierTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 17:15'!
folderName
	^ 'pharoPreferencesTestFolder'! !

!GlobalIdentifierTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 21:05'!
setUp
	super setUp.
	identifier := GlobalIdentifier basicNew initialize.
	preferences := FileLocator workingDirectory / self folderName / 'pharoX' / self fileName.
	preferences ensureDelete.
	self setUpPersistenceStrategy! !

!GlobalIdentifierTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 20:57'!
setUpPersistenceStrategy
	identifier persistenceStrategy preferences: preferences! !

!GlobalIdentifierTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 17:15'!
tearDown
	super tearDown.
	"disk := FileSystem memory."
	preferences ensureDelete.
	(FileLocator workingDirectory / self folderName) 
		ensureDeleteAllChildren; 
		ensureDelete.! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 22:21'!
testBackwardCompatibility
	"Let's say that we have information stored using FUEL, but we use STON.
	We do not have any STON stored value.
	Let's check that we load the FUEL, then stores it as STON."
	| fuelPersistence fuelPrefereces fuelDictionary  |
	fuelPersistence := GlobalIdentifierPersistence fuel.
	fuelPrefereces := preferences parent / 'old-preferences.fuel'.
	fuelPersistence preferences: fuelPrefereces.
	fuelDictionary := Dictionary new.
	fuelDictionary at: #computerUUID put: 42.
	fuelPersistence save: fuelDictionary.
	identifier persistenceStrategy previous: fuelPersistence.
	self deny: identifier computerUUID = 42.
	self assert: fuelPersistence preferences exists.
	identifier ensure.
	self assert: identifier computerUUID equals: 42 asString.
	self assert: identifier persistenceStrategy preferences exists.! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 22:21'!
testBackwardCompatibility2
	"Let's say that we have information stored using both FUEL and STON, and we use STON.
	We will ingnore FUEL file and load STON."
	| fuelPersistence fuelPrefereces fuelDictionary  stonDictionary |
	fuelPersistence := GlobalIdentifierPersistence fuel.
	fuelPrefereces := preferences parent / 'old-preferences.fuel'.
	fuelPersistence preferences: fuelPrefereces.
	fuelDictionary := Dictionary new.
	fuelDictionary at: #computerUUID put: 42.
	fuelPersistence save: fuelDictionary.
	identifier persistenceStrategy previous: fuelPersistence.
	stonDictionary := Dictionary new.
	stonDictionary at: #computerUUID put: 21.
	identifier persistenceStrategy save: stonDictionary.
	self deny: identifier computerUUID = 42.
	self deny: identifier computerUUID = 21.
	self assert: fuelPersistence preferences exists.
	self assert: identifier persistenceStrategy preferences exists.
	identifier ensure.
	self assert: identifier computerUUID equals: 21 asString.
! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 11:32'!
testBackwardCompatibility3
	"Let's say that we have information stored using FUEL but we cannot read the file. 
	We use STON. We do not have any STON stored value.
	Let's check that we keep FUEL file untouched and creates STON file."
	| fuelPersistence fuelPrefereces data |
	fuelPersistence := GlobalIdentifierPersistence fuel.
	fuelPrefereces := preferences parent / 'old-preferences.fuel'.
	fuelPrefereces parent ensureCreateDirectory.
	data := 'some data'.
	fuelPrefereces writeStreamDo: [ :aStream | aStream nextPutAll: data ].
	fuelPersistence preferences: fuelPrefereces.
	identifier persistenceStrategy previous: fuelPersistence.
	self assert: fuelPrefereces exists.
	self assert: fuelPrefereces contents equals: data.
	self deny: identifier persistenceStrategy preferences exists.
	identifier ensure.
	self assert: fuelPrefereces exists.
	self assert: fuelPrefereces contents equals: data.
	self assert: identifier persistenceStrategy preferences exists.! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 11/16/2015 11:46'!
testBackwardCompatibility4
	"Let's say that we have information stored using FUEL but we cannot read the file. 
	We use STON. The STON preference file is broken, we cannot read it.
	Let's check that we keep FUEL file untouched and creates STON file."
	| fuelPersistence fuelPrefereces data dictionary |
	fuelPersistence := GlobalIdentifierPersistence fuel.
	fuelPrefereces := preferences parent / 'old-preferences.fuel'.
	fuelPrefereces parent ensureCreateDirectory.
	data := 'some data'.
	"we create unreadable file."
	fuelPrefereces writeStreamDo: [ :aStream | aStream nextPutAll: data ].
	"we create broken file."
	identifier persistenceStrategy preferences writeStreamDo: [ :aStream | aStream nextPutAll: data ].
	fuelPersistence preferences: fuelPrefereces.
	identifier persistenceStrategy previous: fuelPersistence.
	self assert: fuelPrefereces exists.
	self assert: fuelPrefereces contents equals: data.
	self assert: identifier persistenceStrategy preferences exists.
	self assert: identifier persistenceStrategy preferences contents equals: data.
	identifier ensure.
	self assert: fuelPrefereces exists.
	self assert: fuelPrefereces contents equals: data.
	self assert: identifier persistenceStrategy preferences exists.
	self deny: identifier persistenceStrategy preferences contents = data.
	dictionary := Dictionary new.
	identifier persistenceStrategy load: dictionary.
	self assert: dictionary equals: identifier persistedInformation.! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:09'!
testComputerUUID
	"The computer UUID is not stored immediately because the Pharo Integration Server
	raised building errors when storing the computer UUID on the CI server."
	self assert: identifier computerUUID notNil.
	self assert: identifier computerUUID isString.
	self testDefault.! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 9/1/2015 19:13'!
testDefault
	self deny: preferences exists description: 'The preference file should not exists by default.'.
	self deny: preferences parent exists description: 'The preference directory should not exists by default.'! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:55'!
testEnsure
	"The computer UUID is not stored immediately because the Pharo Integration Server
	raised building errors when storing the computer UUID on the CI server."
	| stored |
	identifier ensure.
	self assert: preferences exists description: 'The preferences should be stored now.'.
	stored := identifier persistenceStrategy load.
	self assert: stored equals: identifier persistedInformation.! !

GlobalIdentifierTest subclass: #GlobalIdentifierWithFuel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Identifier'!

!GlobalIdentifierWithFuel methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 21:17'!
fileName
	^ 'preferences.fuel'! !

!GlobalIdentifierWithFuel methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 20:57'!
setUpPersistenceStrategy
	identifier persistenceStrategy: GlobalIdentifierPersistence fuel.
	identifier persistenceStrategy preferences: preferences! !

GlobalIdentifierTest subclass: #GlobalIdentifierWithSton
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Identifier'!

!GlobalIdentifierWithSton methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 21:17'!
fileName
	^ 'preferences.ston'! !

!GlobalIdentifierWithSton methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 20:58'!
setUpPersistenceStrategy
	identifier persistenceStrategy: GlobalIdentifierPersistence ston.
	identifier persistenceStrategy preferences: preferences! !

Object subclass: #GTDummyEvent
	instanceVariableNames: 'data'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTDummyEvent commentStamp: 'JurajKubelka 11/15/2015 17:53' prior: 0!
I represent an object that is kept by a GTEventCollector. I serve only for the testing purpose.!

!GTDummyEvent methodsFor: 'comparing' stamp: 'JurajKubelka 10/9/2015 15:42'!
= aDummyEvent
	^ self class = aDummyEvent class and: [ 
		self data = aDummyEvent data ]! !

!GTDummyEvent methodsFor: 'accessing' stamp: 'JurajKubelka 10/9/2015 12:10'!
data
	^ data! !

!GTDummyEvent methodsFor: 'accessing' stamp: 'JurajKubelka 10/9/2015 12:10'!
data: anObject
	data := anObject! !

!GTDummyEvent methodsFor: 'comparing' stamp: 'JurajKubelka 10/9/2015 15:43'!
hash
	^ self class hash bitXor: self data! !

Object subclass: #GTEventRecorderTestServer
	instanceVariableNames: 'server url'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests-Core'!

!GTEventRecorderTestServer commentStamp: 'JurajKubelka 11/15/2015 17:50' prior: 0!
I represent a ZnServer that is used for testing purpose. 

I know how to start ZnServer that is started on a random port. For that reason I keep right URL that you can use sending #url message. 
!

!GTEventRecorderTestServer methodsFor: 'initialization' stamp: 'JurajKubelka 11/15/2015 17:04'!
initializeUsingDelegate: aDelegate semaphore: aSemaphore
	| subscription |
	server := ZnServer on: 0.
	server delegate: aDelegate.
	server route: UUID new asString.
	subscription := ZnLogEvent announcer 
							when: ZnServerSocketBoundEvent 
							do: [ :announcement | announcement serverId = server route 
										ifTrue: [ aSemaphore signal ] ]
							for: self.
	server start.
	[ (aSemaphore waitTimeoutMSecs: 200) not ] assert.
	ZnLogEvent announcer removeSubscription: subscription.
	url := ZnUrl new
		scheme: #http;
		host: NetNameResolver loopBackName;
		port: server serverSocket port;
		yourself.! !

!GTEventRecorderTestServer methodsFor: 'accessing' stamp: 'JurajKubelka 11/15/2015 16:45'!
server
	^ server! !

!GTEventRecorderTestServer methodsFor: 'accessing' stamp: 'JurajKubelka 11/15/2015 17:40'!
stop
	server stop! !

!GTEventRecorderTestServer methodsFor: 'subscription' stamp: 'JurajKubelka 11/16/2015 18:27'!
unsubscribeAll
	ZnLogEvent announcer unsubscribe: self! !

!GTEventRecorderTestServer methodsFor: 'accessing' stamp: 'JurajKubelka 11/15/2015 16:45'!
url
	^ url! !

!GTEventRecorderTestServer methodsFor: 'events' stamp: 'JurajKubelka 11/16/2015 19:05'!
when: anAnnouncement do: aBlock
	"Subscribe myself for events that belongs to my ZnServer."
	^ ZnLogEvent announcer 
			when: anAnnouncement 
			do: [ :announcement | announcement serverId = server route ifTrue: [ aBlock cull: announcement ] ]
			for: self.! !
